"""
ValidMind’s Python Developer Framework is a library of developer tools and methods designed to automate
the documentation and validation of your models.

The Developer Framework is designed to be model agnostic. If your model is built in Python, ValidMind's
Python library will provide all the standard functionality without requiring your developers to rewrite any functions.

The Developer Framework provides a rich suite of documentation tools and test plans, from documenting
descriptions of your dataset to testing your models for weak spots and overfit areas. The Developer Framework
helps you automate the generation of model documentation by feeding the ValidMind platform with documentation
artifacts and test results to the ValidMind platform.

To install the client library:

```bash
pip install validmind
```

To initialize the client library, paste the code snippet with the client integration details directly into your
development source code, replacing this example with your own:

```python
import validmind as vm

vm.init(
  api_host = "https://api.dev.vm.validmind.ai/api/v1/tracking/tracking",
  api_key = "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
  api_secret = "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
  project = "<project-identifier>"
)
```

After you have pasted the code snippet into your development source code and executed the code, the Python client
library will register with ValidMind. You can now use the Developer Framework to document and test your models,
and to upload to the ValidMind Platform.
"""
import warnings

# Ignore Numba warnings. We are not requiring this package directly
from numba.core.errors import NumbaDeprecationWarning, NumbaPendingDeprecationWarning

warnings.simplefilter("ignore", category=NumbaDeprecationWarning)
warnings.simplefilter("ignore", category=NumbaPendingDeprecationWarning)

from .api_client import (  # noqa: E402
    init,
    log_metrics,
    log_test_results,
    log_figure,
)

from .client import (  # noqa: E402
    init_dataset,
    init_model,
    init_r_model,
    run_test_plan,
    run_test_suite,
)

__all__ = [  # noqa
    # Framework High Level API
    "datasets",
    "data_validation",
    "init",
    "init_dataset",
    "init_model",
    "init_r_model",
    "model_validation",
    "run_test_plan",
    "run_test_suite",
    "test_plans",
    "test_suites",
    "vm_models",
    # Framework Logging API
    "log_figure",
    "log_metrics",
    "log_test_results",
]
